@@ -6,18 +6,21 @@ drop_bricks(struct notcurses* nc, struct ncplane** arr, int arrcount){
   if(arrcount == 0 || arr == NULL){
     return -1;
   }
-  int stdy, stdx;
+  unsigned stdy, stdx;
   notcurses_term_dim_yx(nc, &stdy, &stdx);
   // an erase+render cycle ought not change the screen, as we duplicated it
   struct timespec iterdelay;
   // 5 * demodelay total
   ns_to_timespec(timespec_to_ns(&demodelay) / arrcount / 2, &iterdelay);
   // we've got a range of up to 10% total blocks falling at any given time. they
-  // accelerate as they fall. [ranges, reange) covers the active range.
+  // accelerate as they fall. [ranges, range) covers the active range.
   int ranges = 0;
   int rangee = 0;
   const int FALLINGMAX = arrcount < 10 ? 1 : arrcount / 10;
-  int speeds[FALLINGMAX];
+  int* speeds = malloc(sizeof(*speeds) * FALLINGMAX);
+  if(speeds == NULL){
+    return -1;
+  }
   while(ranges < arrcount){
     // if we don't have a full set active, and there is another available, go
     // ahead and get it kicked off
@@ -25,7 +28,7 @@ drop_bricks(struct notcurses* nc, struct ncplane** arr, int arrcount){
       if(rangee < arrcount){
         int y;
         ncplane_yx(arr[ranges], &y, NULL);
-        speeds[rangee - ranges] = y < stdy / 2 ? 1 : -1;
+        speeds[rangee - ranges] = y < (int)stdy / 2 ? 1 : -1;
         ++rangee;
       }
     }
@@ -40,7 +43,7 @@ drop_bricks(struct notcurses* nc, struct ncplane** arr, int arrcount){
         int x, y;
         ncplane_yx(ncp, &y, &x);
         if(felloff){
-          if(y + speeds[i] >= stdy || y + speeds[i] + ncplane_dim_y(ncp) < 0){
+          if(y + speeds[i] >= (int)stdy || y + speeds[i] + (int)ncplane_dim_y(ncp) < 0){
             ncplane_destroy(ncp);
             arr[ranges + i] = NULL;
             if(ranges + i + 1 == rangee){
@@ -76,6 +79,7 @@ drop_bricks(struct notcurses* nc, struct ncplane** arr, int arrcount){
       }
     }while(rangee - ranges + 1 >= FALLINGMAX);
   }
+  free(speeds);
   return 0;
 }
 
@@ -98,9 +102,10 @@ shuffle_in(struct ncplane** arr, int count, struct ncplane* n){
 }
 
 // you played yourself https://genius.com/De-la-soul-fallin-lyrics
-int fission_demo(struct notcurses* nc){
+int fission_demo(struct notcurses* nc, uint64_t startns){
+  (void)startns;
   struct ncplane* npl = NULL;
-  int dimx, dimy;
+  unsigned dimx, dimy;
   struct ncplane* stdn = notcurses_stddim_yx(nc, &dimy, &dimx);
   size_t usesize = sizeof(bool) * dimy * dimx;
   bool* usemap = malloc(usesize);
@@ -122,8 +127,8 @@ int fission_demo(struct notcurses* nc){
   //  * newy/newx: actual geometry of current brick
   //  * usey/usex: 
   ncplane_greyscale(stdn);
-  for(int y = 1 ; y < dimy ; ++y){
-    int x = 0;
+  for(unsigned y = 1 ; y < dimy ; ++y){
+    unsigned x = 0;
     while(x < dimx){
       if(usemap[y * dimx + x]){ // skip if we've already been copied
         ++x;
@@ -149,14 +154,14 @@ int fission_demo(struct notcurses* nc){
         goto err;
       }
       // copy the old content into this new ncplane
-      for(int usey = y ; usey < y + newy ; ++usey){
-        for(int usex = x ; usex < x + newx ; ++usex){
+      for(unsigned usey = y ; usey < y + newy ; ++usey){
+        for(unsigned usex = x ; usex < x + newx ; ++usex){
           if(usemap[usey * dimx + usex]){
             newx = usex - x;
             ncplane_resize_simple(n, newy, newx);
             continue;
           }
-          nccell c = CELL_TRIVIAL_INITIALIZER;
+          nccell c = NCCELL_TRIVIAL_INITIALIZER;
           uint16_t smask;
           uint64_t channels;
           char* egc = ncplane_at_yx(stdn, usey, usex, &smask, &channels);
@@ -215,6 +220,7 @@ int fission_demo(struct notcurses* nc){
     }
     assert(ncvisual_decode(ncv) == 1);
     ncvisual_destroy(ncv);
+    ncplane_move_above(npl, stdn);
   }
 #endif
   int ret = drop_bricks(nc, arr, arrcount);
